==> aws-cdk.aws-workspaces-1.80.0.tar.gz: package/lib/workspaces-canned-metrics.generated.d.ts <==
export declare class WorkSpacesMetrics {
    static availableAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static unhealthyAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static sessionLaunchTimeAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static connectionSuccessSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static connectionFailureSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static connectionAttemptSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static inSessionLatencyAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static sessionDisconnectSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static userConnectedSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static stoppedSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static maintenanceSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            WorkspaceId: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-workspaces-1.146.0.tar.gz: package/lib/workspaces-canned-metrics.generated.d.ts <==
export declare class WorkSpacesMetrics {
    static availableAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static unhealthyAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static sessionLaunchTimeAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static connectionSuccessSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static connectionFailureSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static connectionAttemptSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static inSessionLatencyAverage(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static sessionDisconnectSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static userConnectedSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static stoppedSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
    static maintenanceSum(dimensions: {
        WorkspaceId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            WorkspaceId: string;
        };
        statistic: string;
    };
}
